@@ -357,7 +357,7 @@ void ItemContainer::setConfigOverlayVisible(bool visible)
 
 void ItemContainer::contentData_append(QQmlListProperty<QObject> *prop, QObject *object)
 {
-    ItemContainer *container = static_cast<ItemContainer *>(prop->object);
+    auto *container = static_cast<ItemContainer *>(prop->object);
     if (!container) {
         return;
     }
@@ -368,7 +368,7 @@ void ItemContainer::contentData_append(QQmlListProperty<QObject> *prop, QObject
 
 qsizetype ItemContainer::contentData_count(QQmlListProperty<QObject> *prop)
 {
-    ItemContainer *container = static_cast<ItemContainer *>(prop->object);
+    auto *container = static_cast<ItemContainer *>(prop->object);
     if (!container) {
         return 0;
     }
@@ -378,7 +378,7 @@ qsizetype ItemContainer::contentData_count(QQmlListProperty<QObject> *prop)
 
 QObject *ItemContainer::contentData_at(QQmlListProperty<QObject> *prop, qsizetype index)
 {
-    ItemContainer *container = static_cast<ItemContainer *>(prop->object);
+    auto *container = static_cast<ItemContainer *>(prop->object);
     if (!container) {
         return nullptr;
     }
@@ -391,7 +391,7 @@ QObject *ItemContainer::contentData_at(QQmlListProperty<QObject> *prop, qsizetyp
 
 void ItemContainer::contentData_clear(QQmlListProperty<QObject> *prop)
 {
-    ItemContainer *container = static_cast<ItemContainer *>(prop->object);
+    auto *container = static_cast<ItemContainer *>(prop->object);
     if (!container) {
         return;
     }
@@ -401,7 +401,7 @@ void ItemContainer::contentData_clear(QQmlListProperty<QObject> *prop)
 
 QQmlListProperty<QObject> ItemContainer::contentData()
 {
-    return QQmlListProperty<QObject>(this, nullptr, contentData_append, contentData_count, contentData_at, contentData_clear);
+    return {this, nullptr, contentData_append, contentData_count, contentData_at, contentData_clear};
 }
 
 void ItemContainer::geometryChange(const QRectF &newGeometry, const QRectF &oldGeometry)
@@ -499,7 +499,7 @@ bool ItemContainer::childMouseEventFilter(QQuickItem *item, QEvent *event)
         m_closeEditModeTimer->start();
     }
     if (event->type() == QEvent::MouseButtonPress) {
-        QMouseEvent *me = static_cast<QMouseEvent *>(event);
+        auto *me = static_cast<QMouseEvent *>(event);
         if (me->button() != Qt::LeftButton && !(me->buttons() & Qt::LeftButton)) {
             return QQuickItem::childMouseEventFilter(item, event);
         }
@@ -525,7 +525,7 @@ bool ItemContainer::childMouseEventFilter(QQuickItem *item, QEvent *event)
         }
 
     } else if (event->type() == QEvent::MouseMove) {
-        QMouseEvent *me = static_cast<QMouseEvent *>(event);
+        auto *me = static_cast<QMouseEvent *>(event);
 
         if (!m_editMode && QPointF(me->scenePosition() - m_mouseDownPosition).manhattanLength() >= QGuiApplication::styleHints()->startDragDistance()) {
             m_editModeTimer->stop();
