@@ -34,6 +34,7 @@
 #include <sys/socket.h>
 #include <sys/un.h>
 
+#include <algorithm>
 #include <cassert>
 #include <cerrno>
 #include <climits>
@@ -57,7 +58,6 @@
 
 #include <KNotification>
 #include <KSharedConfig>
-#include <QTemporaryFile>
 #include <kactioncollection.h>
 #include <kauthorized.h>
 #include <kconfig.h>
@@ -73,13 +73,10 @@
 
 #include <KScreenLocker/KsldApp>
 
-#include <private/qtx11extras_p.h>
-
+#include <QStandardPaths>
 #include <krandom.h>
-#include <qstandardpaths.h>
 #include <startup_interface.h>
 
-#include "kscreenlocker_interface.h"
 #include "kwinsession_interface.h"
 
 #include <KUpdateLaunchEnvironmentJob>
@@ -100,8 +97,7 @@ namespace
 size_t fileNumberLimit()
 {
     static auto limit = []() -> size_t {
-        struct rlimit limit {
-        };
+        struct rlimit limit = {};
         if (getrlimit(RLIMIT_NOFILE, &limit) != 0) {
             const auto err = errno;
             qCWarning(KSMSERVER) << "Failed to getrlimit:" << strerror(err);
@@ -183,7 +179,7 @@ int numTransports = 0;
 
 Status KSMRegisterClientProc(SmsConn /* smsConn */, SmPointer managerData, char *previousId)
 {
-    KSMClient *client = (KSMClient *)managerData;
+    auto *client = (KSMClient *)managerData;
     client->registerClient(previousId);
     return 1;
 }
@@ -267,7 +263,7 @@ void KSMGetPropertiesProc(SmsConn smsConn, SmPointer managerData)
     auto client = (KSMClient *)managerData;
     auto props = new SmProp *[client->properties.count()];
     int i = 0;
-    foreach (SmProp *prop, client->properties)
+    for (SmProp *prop : std::as_const(client->properties))
         props[i++] = prop;
 
     SmsReturnProperties(smsConn, i, props);
@@ -356,13 +352,15 @@ Status SetAuthentication(int count, IceListenObj *listenObjs, IceAuthDataEntry *
 
         // ICE Auth File
         {
-            IceAuthFileEntry *file_entry = (IceAuthFileEntry *)malloc(sizeof(IceAuthFileEntry));
+            auto *file_entry = (IceAuthFileEntry *)malloc(sizeof(IceAuthFileEntry));
             file_entry->protocol_name = strdup("ICE");
             file_entry->protocol_data = NULL;
             file_entry->protocol_data_length = 0;
             file_entry->network_id = IceGetListenConnectionString(listenObjs[i / 2]);
             file_entry->auth_name = strdup("MIT-MAGIC-COOKIE-1");
-            file_entry->auth_data = strdup((*authDataEntries)[i].auth_data);
+            if (file_entry->auth_data = (char *)malloc(MAGIC_COOKIE_LEN)) {
+                memcpy(file_entry->auth_data, (*authDataEntries)[i].auth_data, MAGIC_COOKIE_LEN);
+            }
             file_entry->auth_data_length = MAGIC_COOKIE_LEN;
             if (IceWriteAuthFileEntry(fp, file_entry) == 0) {
                 qWarning("Failed to write ice auth file entry");
@@ -380,13 +378,15 @@ Status SetAuthentication(int count, IceListenObj *listenObjs, IceAuthDataEntry *
 
         // XSMP Auth file
         {
-            IceAuthFileEntry *file_entry = (IceAuthFileEntry *)malloc(sizeof(IceAuthFileEntry));
+            auto *file_entry = (IceAuthFileEntry *)malloc(sizeof(IceAuthFileEntry));
             file_entry->protocol_name = strdup("XSMP");
             file_entry->protocol_data = NULL;
             file_entry->protocol_data_length = 0;
             file_entry->network_id = IceGetListenConnectionString(listenObjs[i / 2]);
             file_entry->auth_name = strdup("MIT-MAGIC-COOKIE-1");
-            file_entry->auth_data = strdup((*authDataEntries)[i + 1].auth_data);
+            if (file_entry->auth_data = (char *)malloc(MAGIC_COOKIE_LEN)) {
+                memcpy(file_entry->auth_data, (*authDataEntries)[i + 1].auth_data, MAGIC_COOKIE_LEN);
+            }
             file_entry->auth_data_length = MAGIC_COOKIE_LEN;
             if (IceWriteAuthFileEntry(fp, file_entry) == 0) {
                 qWarning("Failed to write xsmp ice auth file entry");
@@ -742,13 +742,11 @@ void KSMServer::deleteClient(KSMClient *client)
         handlePendingInteractions();
     }
     delete client;
-    if (state == Shutdown || state == Checkpoint || state == ClosingSubSession) {
+    if (state == Shutdown || state == Checkpoint) {
         completeShutdownOrCheckpoint();
     }
     if (state == Killing) {
         completeKilling();
-    } else if (state == KillingSubSession) {
-        completeKillingSubSession();
     }
 }
 
@@ -771,7 +769,7 @@ void KSMServer::newConnection(int /*socket*/)
         for (const auto &client : clients) {
             QString program = client->program();
             if (program.isEmpty() && !client->restartCommand().isEmpty()) {
-                program = client->restartCommand().first();
+                program = client->restartCommand().constFirst();
             }
             if (program.isEmpty()) {
                 program = i18nc("@label an unknown executable is using resources", "[unknown]");
@@ -839,7 +837,7 @@ void KSMServer::discardSession()
 {
     KConfigGroup config(KSharedConfig::openConfig(), sessionGroup);
     int count = config.readEntry("count", 0);
-    foreach (KSMClient *c, clients) {
+    for (KSMClient *c : std::as_const(clients)) {
         QStringList discardCommand = c->discardCommand();
         if (discardCommand.isEmpty()) {
             continue;
@@ -848,7 +846,7 @@ void KSMServer::discardSession()
         // discardCommand before we execute it. This used to be the
         // case up to KDE and Qt < 3.1
         int i = 1;
-        while (i <= count && config.readPathEntry(QStringLiteral("discardCommand") + QString::number(i), QStringList()) != discardCommand) {
+        while (i <= count && config.readPathEntry(QString(u"discardCommand" + QString::number(i)), QStringList()) != discardCommand) {
             i++;
         }
         if (i <= count) {
@@ -891,7 +889,7 @@ void KSMServer::storeSession()
     auto reply = m_kwinInterface->finishSaveSession(currentSession());
     reply.waitForFinished(); // boo!
 
-    foreach (KSMClient *c, clients) {
+    for (KSMClient *c : std::as_const(clients)) {
         const int restartHint = c->restartStyleHint();
         if (restartHint == SmRestartNever) {
             continue;
@@ -901,9 +899,6 @@ void KSMServer::storeSession()
         if (program.isEmpty() && restartCommand.isEmpty()) {
             continue;
         }
-        if (state == ClosingSubSession && !clientsToSave.contains(c)) {
-            continue;
-        }
 
         // 'program' might be (mostly) fullpath, or (sometimes) just the name.
         // 'name' is just the name.
@@ -916,12 +911,12 @@ void KSMServer::storeSession()
 
         count++;
         const QString n = QString::number(count);
-        cg.writeEntry(QStringLiteral("program") + n, program);
-        cg.writeEntry(QStringLiteral("clientId") + n, c->clientId());
-        cg.writeEntry(QStringLiteral("restartCommand") + n, restartCommand);
-        cg.writePathEntry(QStringLiteral("discardCommand") + n, c->discardCommand());
-        cg.writeEntry(QStringLiteral("restartStyleHint") + n, restartHint);
-        cg.writeEntry(QStringLiteral("userId") + n, c->userId());
+        cg.writeEntry(QString(u"program" + n), program);
+        cg.writeEntry(QString(u"clientId" + n), c->clientId());
+        cg.writeEntry(QString(u"restartCommand" + n), restartCommand);
+        cg.writePathEntry(QString(u"discardCommand" + n), c->discardCommand());
+        cg.writeEntry(QString(u"restartStyleHint" + n), restartHint);
+        cg.writeEntry(QString(u"userId" + n), c->userId());
     }
     cg.writeEntry("count", count);
 
@@ -1000,25 +995,13 @@ void KSMServer::restoreSession()
     });
 }
 
-void KSMServer::restoreSubSession(const QString &name)
-{
-    sessionGroup = SUBSESSION_PREFIX + name;
-
-    KConfigGroup configSessionGroup(KSharedConfig::openConfig(), sessionGroup);
-    int count = configSessionGroup.readEntry("count", 0);
-    appsToStart = count;
-
-    state = RestoringSubSession;
-    tryRestore();
-}
-
 void KSMServer::clientRegistered(const char * /* previousId */)
 {
 }
 
 void KSMServer::tryRestore()
 {
-    if (state != Restoring && state != RestoringSubSession) {
+    if (state != Restoring) {
         return;
     }
     KConfigGroup config(KSharedConfig::openConfig(), sessionGroup);
@@ -1078,14 +1061,14 @@ void KSMServer::tryRestore()
         // We only discard the entries here because a violating app will get all entries disabled, not just the ones in
         // excess. So we need to loop all entries twice: once to establish the in-excess apps, and again to actually start
         // (or not).
-        const bool dontStart = std::any_of(dontStartEntries.cbegin(), dontStartEntries.cend(), [&entry](const auto &dontStartEntry) {
+        const bool dontStart = std::ranges::any_of(dontStartEntries, [&entry](const auto &dontStartEntry) {
             return dontStartEntry.clientId == entry.clientId;
         });
         if (dontStart) {
             continue;
         }
 
-        const bool alreadyStarted = std::any_of(clients.cbegin(), clients.cend(), [&entry](const auto &client) {
+        const bool alreadyStarted = std::ranges::any_of(clients, [&entry](const auto &client) {
             return QString::fromLocal8Bit(client->clientId()) == entry.clientId;
         });
         if (alreadyStarted) {
@@ -1101,8 +1084,6 @@ void KSMServer::tryRestore()
     // all done
     if (state == Restoring) {
         Q_EMIT sessionRestored();
-    } else { // subsession
-        Q_EMIT subSessionOpened();
     }
     state = Idle;
 }
@@ -1112,9 +1093,4 @@ void KSMServer::startupDone()
     state = Idle;
 }
 
-void KSMServer::openSwitchUserDialog()
-{
-    // this method exists only for compatibility. Users should ideally call this directly
-    OrgKdeScreensaverInterface iface(QStringLiteral("org.freedesktop.ScreenSaver"), QStringLiteral("/ScreenSaver"), QDBusConnection::sessionBus());
-    iface.SwitchUser();
-}
+#include "moc_server.cpp"
